/*********************************************************************
----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for RSKRX610 Starter-Kit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** Addresses of sfrs and peripheral identifiers ****************/
#define P8_BASE_ADDR       (0x0008C008u)

/****** SFRs and identifiers used for LED demo **********************/
#define P8_DDR             (*(volatile unsigned char*) (P8_BASE_ADDR + 0x00u))
#define P8_DR              (*(volatile unsigned char*) (P8_BASE_ADDR + 0x20u))

/****** Assign LEDs to Ports ****************************************/
#define LED0_BIT           (3u)                   // LED 0 on RSKRX610
#define LED1_BIT           (4u)                   // LED 1 on RSKRX610
#define LED0_MASK          (1u << LED0_BIT)
#define LED1_MASK          (1u << LED1_BIT)
#define LED_MASK_ALL       (LED0_MASK | LED1_MASK)

#define LED_PORT_DATA      P8_DR
#define LED_PORT_DIRECTION P8_DDR

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  LED_PORT_DATA      |= LED_MASK_ALL;   // Switch off leds initially (active low)
  LED_PORT_DIRECTION |= LED_MASK_ALL;   // Switch LED-Port to output
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    LED_PORT_DATA &= ~(LED0_MASK);      // Switch LED on, active low
  } else if (Index == 1) {
    LED_PORT_DATA &= ~(LED1_MASK);      // Switch LED on, active low
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    LED_PORT_DATA |= (LED0_MASK);  // Switch LED off, set port high
  } else if (Index == 1) {
    LED_PORT_DATA |= (LED1_MASK);  // Switch LED off, set port high
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    LED_PORT_DATA ^= LED0_MASK;
  } else if (Index == 1) {
    LED_PORT_DATA ^= LED1_MASK;
  }
}

/****** End Of File  ************************************************/
